@@ -10,6 +10,7 @@ import publication
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_ec2._jsii
+import aws_cdk.aws_efs._jsii
 import aws_cdk.aws_events._jsii
 import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_logs._jsii
@@ -20,7 +21,9 @@ import aws_cdk.core._jsii
 import aws_cdk.cx_api._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-lambda", "1.48.0", __name__[0:-6], "aws-lambda@1.48.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-cdk/aws-lambda", "1.50.0", __name__[0:-6], "aws-lambda@1.50.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
